Struct libpna::WriteOption
source · pub struct WriteOption { /* private fields */ }Implementations
sourceimpl WriteOption
impl WriteOption
sourcepub const fn store() -> Self
pub const fn store() -> Self
A new WriteOption to simply store.
Examples
use libpna::{EntryBuilder, WriteOption};
EntryBuilder::new_file("example.txt".try_into().unwrap(), WriteOption::store()).unwrap();sourcepub const fn builder() -> WriteOptionBuilder
pub const fn builder() -> WriteOptionBuilder
Returns a builder for WriteOption.
Returns
WriteOptionBuilder Builder object for WriteOption.
Examples
use libpna::WriteOption;
let builder = WriteOption::builder();sourcepub fn into_builder(self) -> WriteOptionBuilder
pub fn into_builder(self) -> WriteOptionBuilder
Converts WriteOption into a WriteOptionBuilder.
Returns
WriteOptionBuilder: Builder object for WriteOption.
Examples
use libpna::WriteOption;
let write_option = WriteOption::builder().build();
let builder = write_option.into_builder();Trait Implementations
sourceimpl Clone for WriteOption
impl Clone for WriteOption
sourcefn clone(&self) -> WriteOption
fn clone(&self) -> WriteOption
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for WriteOption
impl Debug for WriteOption
sourceimpl From<WriteOption> for WriteOptionBuilder
impl From<WriteOption> for WriteOptionBuilder
sourcefn from(value: WriteOption) -> Self
fn from(value: WriteOption) -> Self
Converts to this type from the input type.
sourceimpl Hash for WriteOption
impl Hash for WriteOption
sourceimpl Ord for WriteOption
impl Ord for WriteOption
sourcefn cmp(&self, other: &WriteOption) -> Ordering
fn cmp(&self, other: &WriteOption) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for WriteOption
impl PartialEq for WriteOption
sourcefn eq(&self, other: &WriteOption) -> bool
fn eq(&self, other: &WriteOption) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for WriteOption
impl PartialOrd for WriteOption
sourcefn partial_cmp(&self, other: &WriteOption) -> Option<Ordering>
fn partial_cmp(&self, other: &WriteOption) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for WriteOption
impl StructuralEq for WriteOption
impl StructuralPartialEq for WriteOption